@@ -5,7 +5,7 @@ import sys
 import time
 from concurrent.futures import Future
 from time import sleep
-from typing import Callable, List, Optional
+from typing import Any, Callable, Optional, Union
 
 from executorlib.base.executor import ExecutorBase, cancel_items_in_queue
 from executorlib.standalone.command import get_command_path
@@ -23,7 +23,9 @@ from executorlib.standalone.thread import RaisingThread
 
 
 class ExecutorBroker(ExecutorBase):
-    def submit(self, fn: callable, *args, resource_dict: dict = {}, **kwargs) -> Future:
+    def submit(  # type: ignore
+        self, fn: Callable, *args, resource_dict: Optional[dict] = None, **kwargs
+    ) -> Future:
         """
         Submits a callable to be executed with the given arguments.
 
@@ -31,7 +33,7 @@ class ExecutorBroker(ExecutorBase):
         a Future instance representing the execution of the callable.
 
         Args:
-            fn (callable): function to submit for execution
+            fn (Callable): function to submit for execution
             args: arguments for the submitted function
             kwargs: keyword arguments for the submitted function
             resource_dict (dict): resource dictionary, which defines the resources used for the execution of the
@@ -48,10 +50,15 @@ class ExecutorBroker(ExecutorBase):
         Returns:
             Future: A Future representing the given call.
         """
+        if resource_dict is None:
+            resource_dict = {}
         check_resource_dict_is_empty(resource_dict=resource_dict)
         check_resource_dict(function=fn)
-        f = Future()
-        self._future_queue.put({"fn": fn, "args": args, "kwargs": kwargs, "future": f})
+        f: Future = Future()
+        if self._future_queue is not None:
+            self._future_queue.put(
+                {"fn": fn, "args": args, "kwargs": kwargs, "future": f}
+            )
         return f
 
     def shutdown(self, wait: bool = True, *, cancel_futures: bool = False):
@@ -68,19 +75,20 @@ class ExecutorBroker(ExecutorBase):
                 futures. Futures that are completed or running will not be
                 cancelled.
         """
-        if cancel_futures:
-            cancel_items_in_queue(que=self._future_queue)
-        if self._process is not None:
-            for _ in range(len(self._process)):
-                self._future_queue.put({"shutdown": True, "wait": wait})
-            if wait:
-                for process in self._process:
-                    process.join()
-                self._future_queue.join()
+        if self._future_queue is not None:
+            if cancel_futures:
+                cancel_items_in_queue(que=self._future_queue)
+            if isinstance(self._process, list):
+                for _ in range(len(self._process)):
+                    self._future_queue.put({"shutdown": True, "wait": wait})
+                if wait:
+                    for process in self._process:
+                        process.join()
+                    self._future_queue.join()
         self._process = None
         self._future_queue = None
 
-    def _set_process(self, process: List[RaisingThread]):
+    def _set_process(self, process: list[RaisingThread]):  # type: ignore
         """
         Set the process for the executor.
 
@@ -88,8 +96,8 @@ class ExecutorBroker(ExecutorBase):
             process (List[RaisingThread]): The process for the executor.
         """
         self._process = process
-        for process in self._process:
-            process.start()
+        for process_instance in self._process:
+            process_instance.start()
 
 
 class InteractiveExecutor(ExecutorBroker):
@@ -108,7 +116,7 @@ class InteractiveExecutor(ExecutorBroker):
     Examples:
 
         >>> import numpy as np
-        >>> from executorlib.interactive.executor import InteractiveExecutor
+        >>> from executorlib.interactive.shared import InteractiveExecutor
         >>>
         >>> def calc(i, j, k):
         >>>     from mpi4py import MPI
@@ -129,12 +137,15 @@ class InteractiveExecutor(ExecutorBroker):
     def __init__(
         self,
         max_workers: int = 1,
-        executor_kwargs: dict = {},
-        spawner: BaseSpawner = MpiExecSpawner,
+        executor_kwargs: Optional[dict] = None,
+        spawner: type[BaseSpawner] = MpiExecSpawner,
     ):
-        super().__init__(max_cores=executor_kwargs.get("max_cores", None))
+        if executor_kwargs is None:
+            executor_kwargs = {}
+        super().__init__(max_cores=executor_kwargs.get("max_cores"))
         executor_kwargs["future_queue"] = self._future_queue
         executor_kwargs["spawner"] = spawner
+        executor_kwargs["queue_join_on_shutdown"] = False
         self._set_process(
             process=[
                 RaisingThread(
@@ -162,7 +173,7 @@ class InteractiveStepExecutor(ExecutorBase):
     Examples:
 
         >>> import numpy as np
-        >>> from executorlib.interactive.executor import InteractiveStepExecutor
+        >>> from executorlib.interactive.shared import InteractiveStepExecutor
         >>>
         >>> def calc(i, j, k):
         >>>     from mpi4py import MPI
@@ -170,7 +181,7 @@ class InteractiveStepExecutor(ExecutorBase):
         >>>     rank = MPI.COMM_WORLD.Get_rank()
         >>>     return np.array([i, j, k]), size, rank
         >>>
-        >>> with PyFluxStepExecutor(max_cores=2) as p:
+        >>> with InteractiveStepExecutor(max_cores=2) as p:
         >>>     fs = p.submit(calc, 2, j=4, k=3, resource_dict={"cores": 2})
         >>>     print(fs.result())
 
@@ -182,10 +193,12 @@ class InteractiveStepExecutor(ExecutorBase):
         self,
         max_cores: Optional[int] = None,
         max_workers: Optional[int] = None,
-        executor_kwargs: dict = {},
-        spawner: BaseSpawner = MpiExecSpawner,
+        executor_kwargs: Optional[dict] = None,
+        spawner: type[BaseSpawner] = MpiExecSpawner,
     ):
-        super().__init__(max_cores=executor_kwargs.get("max_cores", None))
+        if executor_kwargs is None:
+            executor_kwargs = {}
+        super().__init__(max_cores=executor_kwargs.get("max_cores"))
         executor_kwargs["future_queue"] = self._future_queue
         executor_kwargs["spawner"] = spawner
         executor_kwargs["max_cores"] = max_cores
@@ -201,10 +214,11 @@ class InteractiveStepExecutor(ExecutorBase):
 def execute_parallel_tasks(
     future_queue: queue.Queue,
     cores: int = 1,
-    spawner: BaseSpawner = MpiExecSpawner,
+    spawner: type[BaseSpawner] = MpiExecSpawner,
     hostname_localhost: Optional[bool] = None,
     init_function: Optional[Callable] = None,
     cache_directory: Optional[str] = None,
+    queue_join_on_shutdown: bool = True,
     **kwargs,
 ) -> None:
     """
@@ -221,8 +235,9 @@ def execute_parallel_tasks(
                                      points to the same address as localhost. Still MacOS >= 12 seems to disable
                                      this look up for security reasons. So on MacOS it is required to set this
                                      option to true
-       init_function (callable): optional function to preset arguments for functions which are submitted later
+       init_function (Callable): optional function to preset arguments for functions which are submitted later
        cache_directory (str, optional): The directory to store cache files. Defaults to "cache".
+       queue_join_on_shutdown (bool): Join communication queue when thread is closed. Defaults to True.
     """
     interface = interface_bootup(
         command_lst=_get_backend_path(
@@ -237,12 +252,13 @@ def execute_parallel_tasks(
         )
     while True:
         task_dict = future_queue.get()
-        if "shutdown" in task_dict.keys() and task_dict["shutdown"]:
+        if "shutdown" in task_dict and task_dict["shutdown"]:
             interface.shutdown(wait=task_dict["wait"])
             future_queue.task_done()
-            future_queue.join()
+            if queue_join_on_shutdown:
+                future_queue.join()
             break
-        elif "fn" in task_dict.keys() and "future" in task_dict.keys():
+        elif "fn" in task_dict and "future" in task_dict:
             if cache_directory is None:
                 _execute_task(
                     interface=interface, task_dict=task_dict, future_queue=future_queue
@@ -258,7 +274,7 @@ def execute_parallel_tasks(
 
 def execute_separate_tasks(
     future_queue: queue.Queue,
-    spawner: BaseSpawner = MpiExecSpawner,
+    spawner: type[BaseSpawner] = MpiExecSpawner,
     max_cores: Optional[int] = None,
     max_workers: Optional[int] = None,
     hostname_localhost: Optional[bool] = None,
@@ -282,20 +298,21 @@ def execute_separate_tasks(
                                      this look up for security reasons. So on MacOS it is required to set this
                                      option to true
     """
-    active_task_dict = {}
-    process_lst, qtask_lst = [], []
-    if "cores" not in kwargs.keys():
+    active_task_dict: dict = {}
+    process_lst: list = []
+    qtask_lst: list = []
+    if "cores" not in kwargs:
         kwargs["cores"] = 1
     while True:
         task_dict = future_queue.get()
-        if "shutdown" in task_dict.keys() and task_dict["shutdown"]:
+        if "shutdown" in task_dict and task_dict["shutdown"]:
             if task_dict["wait"]:
                 _ = [process.join() for process in process_lst]
             future_queue.task_done()
             future_queue.join()
             break
-        elif "fn" in task_dict.keys() and "future" in task_dict.keys():
-            qtask = queue.Queue()
+        elif "fn" in task_dict and "future" in task_dict:
+            qtask: queue.Queue = queue.Queue()
             process, active_task_dict = _submit_function_to_separate_process(
                 task_dict=task_dict,
                 qtask=qtask,
@@ -334,18 +351,14 @@ def execute_tasks_with_dependencies(
         except queue.Empty:
             task_dict = None
         if (  # shutdown the executor
-            task_dict is not None
-            and "shutdown" in task_dict.keys()
-            and task_dict["shutdown"]
+            task_dict is not None and "shutdown" in task_dict and task_dict["shutdown"]
         ):
             executor.shutdown(wait=task_dict["wait"])
             future_queue.task_done()
             future_queue.join()
             break
         elif (  # handle function submitted to the executor
-            task_dict is not None
-            and "fn" in task_dict.keys()
-            and "future" in task_dict.keys()
+            task_dict is not None and "fn" in task_dict and "future" in task_dict
         ):
             future_lst, ready_flag = _get_future_objects_from_input(task_dict=task_dict)
             if len(future_lst) == 0 or ready_flag:
@@ -429,7 +442,7 @@ def _wait_for_free_slots(
     return active_task_dict
 
 
-def _submit_waiting_task(wait_lst: List[dict], executor_queue: queue.Queue) -> list:
+def _submit_waiting_task(wait_lst: list[dict], executor_queue: queue.Queue) -> list:
     """
     Submit the waiting tasks, which future inputs have been completed, to the executor
 
@@ -442,7 +455,7 @@ def _submit_waiting_task(wait_lst: List[dict], executor_queue: queue.Queue) -> l
     """
     wait_tmp_lst = []
     for task_wait_dict in wait_lst:
-        if all([future.done() for future in task_wait_dict["future_lst"]]):
+        if all(future.done() for future in task_wait_dict["future_lst"]):
             del task_wait_dict["future_lst"]
             task_wait_dict["args"], task_wait_dict["kwargs"] = _update_futures_in_input(
                 args=task_wait_dict["args"], kwargs=task_wait_dict["kwargs"]
@@ -453,7 +466,7 @@ def _submit_waiting_task(wait_lst: List[dict], executor_queue: queue.Queue) -> l
     return wait_tmp_lst
 
 
-def _update_futures_in_input(args: tuple, kwargs: dict):
+def _update_futures_in_input(args: tuple, kwargs: dict) -> tuple[tuple, dict]:
     """
     Evaluate future objects in the arguments and keyword arguments by calling future.result()
 
@@ -465,7 +478,7 @@ def _update_futures_in_input(args: tuple, kwargs: dict):
         tuple, dict: arguments and keyword arguments with each future object in them being evaluated
     """
 
-    def get_result(arg):
+    def get_result(arg: Union[list[Future], Future]) -> Any:
         if isinstance(arg, Future):
             return arg.result()
         elif isinstance(arg, list):
@@ -473,7 +486,7 @@ def _update_futures_in_input(args: tuple, kwargs: dict):
         else:
             return arg
 
-    args = [get_result(arg=arg) for arg in args]
+    args = tuple([get_result(arg=arg) for arg in args])
     kwargs = {key: get_result(arg=value) for key, value in kwargs.items()}
     return args, kwargs
 
@@ -484,7 +497,7 @@ def _get_future_objects_from_input(task_dict: dict):
 
     Args:
         task_dict (dict): task submitted to the executor as dictionary. This dictionary has the following keys
-                          {"fn": callable, "args": (), "kwargs": {}, "resource_dict": {}}
+                          {"fn": Callable, "args": (), "kwargs": {}, "resource_dict": {}}
 
     Returns:
         list, boolean: list of future objects and boolean flag if all future objects are already done
@@ -510,7 +523,7 @@ def _submit_function_to_separate_process(
     task_dict: dict,
     active_task_dict: dict,
     qtask: queue.Queue,
-    spawner: BaseSpawner,
+    spawner: type[BaseSpawner],
     executor_kwargs: dict,
     max_cores: Optional[int] = None,
     max_workers: Optional[int] = None,
@@ -520,7 +533,7 @@ def _submit_function_to_separate_process(
     Submit function to be executed in separate Python process
     Args:
         task_dict (dict): task submitted to the executor as dictionary. This dictionary has the following keys
-                          {"fn": callable, "args": (), "kwargs": {}, "resource_dict": {}}
+                          {"fn": Callable, "args": (), "kwargs": {}, "resource_dict": {}}
         active_task_dict (dict): Dictionary containing the future objects and the number of cores they require
         qtask (queue.Queue): Queue to communicate with the thread linked to the process executing the python function
         spawner (BaseSpawner): Interface to start process on selected compute resources
@@ -543,7 +556,7 @@ def _submit_function_to_separate_process(
     resource_dict = task_dict.pop("resource_dict").copy()
     qtask.put(task_dict)
     qtask.put({"shutdown": True, "wait": True})
-    if "cores" not in resource_dict.keys() or (
+    if "cores" not in resource_dict or (
         resource_dict["cores"] == 1 and executor_kwargs["cores"] >= 1
     ):
         resource_dict["cores"] = executor_kwargs["cores"]
@@ -582,7 +595,7 @@ def _execute_task(
     Args:
         interface (SocketInterface): socket interface for zmq communication
         task_dict (dict): task submitted to the executor as dictionary. This dictionary has the following keys
-                          {"fn": callable, "args": (), "kwargs": {}, "resource_dict": {}}
+                          {"fn": Callable, "args": (), "kwargs": {}, "resource_dict": {}}
         future_queue (Queue): Queue for receiving new tasks.
     """
     f = task_dict.pop("future")
@@ -610,7 +623,7 @@ def _execute_task_with_cache(
     Args:
         interface (SocketInterface): socket interface for zmq communication
         task_dict (dict): task submitted to the executor as dictionary. This dictionary has the following keys
-                          {"fn": callable, "args": (), "kwargs": {}, "resource_dict": {}}
+                          {"fn": Callable, "args": (), "kwargs": {}, "resource_dict": {}}
         future_queue (Queue): Queue for receiving new tasks.
         cache_directory (str): The directory to store cache files.
     """
